import path from "path"
import fs from "fs"

const _defaultLocale = 'fr'
const _localePath = path.dirname(process.argv[1]) + '/locales'
const _locales = {
	default: null
}

const init = () => {
	_locales[_defaultLocale] = JSON.parse(fs.readFileSync(_localePath + '/' + _defaultLocale + '.json'))
	_locales.default = _locales[_defaultLocale]
}

if(! _locales.default) init()

const capitalize = (string) => {
	return ( string && String(string[0]).toUpperCase() + String(string).slice(1)) || ""
}
const getLocaleData = (locale) => {
	if(! locale) locale = _defaultLocale
	if(! _locales[locale]) {
		if(! fs.existsSync(_localePath + '/' + locale + '.json')) {
			return _locales.default
		}
		_locales[locale] = JSON.parse(fs.readFileSync(_localePath + '/' + locale + '.json'))
	}
	return _locales[locale]
}

const getString = (key, locale) => {
	const localeData = getLocaleData(locale)
	if(localeData.strings[key]) return localeData.strings[key]
	else if(_locales.default.strings[key]) return _locales.default.strings[key]
	return key
}

export default {
	capitalize,
	getString,
}